@@ -70,6 +70,31 @@ pub enum BinOp {
     Coalesce,
 }
 
+impl BinOp {
+    pub fn strength(&self) -> i32 {
+        // Is there some canonical reference for these? I'm guessing we want to
+        // copy SQL for them. At the moment it's just me guessing.
+        match self {
+            BinOp::Coalesce => 15,
+            BinOp::Mod => 11,
+            BinOp::Mul | BinOp::Div => 10,
+            BinOp::Sub | BinOp::Add => 9,
+            BinOp::Gt | BinOp::Lt | BinOp::Gte | BinOp::Lte => 5,
+            BinOp::Eq | BinOp::Ne => 4,
+            BinOp::And | BinOp::Or => 3,
+        }
+    }
+}
+impl Item {
+    pub(crate) fn strength(&self) -> i32 {
+        // TODO: Do we need to include these for more than BinOps?
+        match self {
+            Item::Binary { op, .. } => op.strength(),
+            _ => 20,
+        }
+    }
+}
+
 #[derive(Debug, PartialEq, Clone, Serialize, Deserialize, strum::EnumString)]
 pub enum UnOp {
     #[strum(to_string = "-")]
@@ -206,16 +231,29 @@ impl Display for Item {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         match self {
             Item::Ident(s) => {
-                f.write_str(s)?;
+                write!(f, "`{s}`")?;
             }
             Item::Assign(ne) => {
-                write!(f, "{} = {}", ne.name, ne.expr.item)?;
+                match ne.expr.item {
+                    Item::FuncCall(_) => {
+                        write!(f, "{} = ({})", ne.name, ne.expr.item)?;
+                    }
+
+                    _ => {
+                        write!(f, "{} = {}", ne.name, ne.expr.item)?;
+                    }
+                };
             }
             Item::NamedArg(ne) => {
                 write!(f, "{}:{}", ne.name, ne.expr.item)?;
             }
             Item::Query(query) => {
-                write!(f, "prql dialect: {}\n\n", query.dialect)?;
+                write!(f, "prql dialect:{}", query.dialect)?;
+                match query.version {
+                    Some(version) => write!(f, " version:{}", version)?,
+                    None => {}
+                };
+                write!(f, "\n\n")?;
 
                 for node in &query.nodes {
                     match &node.item {
@@ -223,8 +261,9 @@ impl Display for Item {
                             for node in &p.nodes {
                                 writeln!(f, "{}", node.item)?;
                             }
+                            f.write_char('\n')?;
                         }
-                        _ => write!(f, "{}", node.item)?,
+                        _ => writeln!(f, "{}\n", node.item)?,
                     }
                 }
             }
@@ -258,10 +297,22 @@ impl Display for Item {
                 for arg in &func_def.named_params {
                     write!(f, " {}", arg.0.item)?;
                 }
-                write!(f, " = {}\n\n", func_def.body.item)?;
+                write!(f, " -> {}\n\n", func_def.body.item)?;
             }
             Item::Table(table) => {
-                write!(f, "table {} = {}\n\n", table.name, table.pipeline.item)?;
+                match table.pipeline.item {
+                    Item::FuncCall(_) => {
+                        write!(
+                            f,
+                            "table {} = (\n  {}\n)\n\n",
+                            table.name, table.pipeline.item
+                        )?;
+                    }
+
+                    _ => {
+                        write!(f, "table {} = {}\n\n", table.name, table.pipeline.item)?;
+                    }
+                };
             }
             Item::List(nodes) => {
                 if nodes.is_empty() {
@@ -286,10 +337,18 @@ impl Display for Item {
                 }
             }
             Item::Binary { op, left, right } => {
-                write!(f, "{} {op} {}", left.item, right.item)?;
+                match left.item {
+                    Item::FuncCall(_) => write!(f, "( {} )", left.item)?,
+                    _ => write!(f, "{}", left.item)?,
+                };
+                write!(f, " {op} ")?;
+                match right.item {
+                    Item::FuncCall(_) => write!(f, "( {} )", right.item)?,
+                    _ => write!(f, "{}", right.item)?,
+                };
             }
             Item::Unary { op, expr } => match op {
-                UnOp::Neg => write!(f, "!{}", expr.item)?,
+                UnOp::Neg => write!(f, "-{}", expr.item)?,
                 UnOp::Not => write!(f, "not {}", expr.item)?,
             },
             Item::FuncCall(func_call) => {
@@ -299,7 +358,17 @@ impl Display for Item {
                     write!(f, " {name}: {}", arg.item)?;
                 }
                 for arg in &func_call.args {
-                    write!(f, " {}", arg.item)?;
+                    match arg.item {
+                        Item::FuncCall(_) => {
+                            writeln!(f, " (")?;
+                            writeln!(f, "  {}", arg.item)?;
+                            f.write_char(')')?;
+                        }
+
+                        _ => {
+                            write!(f, " {}", arg.item)?;
+                        }
+                    }
                 }
             }
             Item::SString(parts) => {
@@ -312,7 +381,7 @@ impl Display for Item {
                 write!(f, "{}{}", i.n, i.unit)?;
             }
             Item::Windowed(w) => {
-                write!(f, "{:?}", w.expr)?;
+                write!(f, "{}", w.expr.item)?;
             }
             Item::Type(typ) => {
                 f.write_char('<')?;
@@ -320,7 +389,7 @@ impl Display for Item {
                 f.write_char('>')?;
             }
             Item::Literal(literal) => {
-                write!(f, "{:?}", literal)?;
+                write!(f, "{}", literal)?;
             }
         }
         Ok(())
