@@ -1,3 +1,4 @@
+mod distinct;
 mod materializer;
 mod translator;
 mod un_group;
@@ -13,9 +14,9 @@ use crate::semantic;
 /// Resolve all variable and function calls using SQL stdlib and then translate AST into SQL.
 pub fn resolve_and_translate(mut query: Query) -> Result<String> {
     let std_lib = load_std_lib()?;
-    let (_, context) = semantic::resolve(std_lib, None)?;
+    let (_, context) = semantic::resolve_names(std_lib, None)?;
 
-    let (nodes, context) = semantic::resolve(query.nodes, Some(context))?;
+    let (nodes, context) = semantic::resolve_names(query.nodes, Some(context))?;
 
     query.nodes = nodes;
     translate(query, context)
